bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel <- function(x,ngrid=200,typeDensEst=1,rangeObs.x=rangeObs,rangeObs.y=rangeObs,weightsObs=rep(1,dim(x)[1]),limDensity=0,alpha=0.5,smoothMethod="C2",figure=FALSE,rangeObs=c(0.05,4),S=cov(x),h.norm.x.pilot=h.select(x=x,weights=weightsObs,nbins=0,method=method.h),h.norm.marg.density=h.select(x=x[,2],weights=weightsObs,nbins=0,method=method.h),provide.h=FALSE,provide.lambda=FALSE,lambdas.provide=rep(1,dim(x)[1]),method.h="normal",new.evalPoints.x=seq(rangeObs.x[1],rangeObs.x[2],length=ngrid),kernelType="Gaussian",ergodicDistr=TRUE,obsNormalized=TRUE){

##Bivariate kernel for not symmetric observations via parallel computation
##See Silverman (1986) pp. 77-78 and Fukunaga (1972), p. 175

  # x: matrix of observations with N rows and 2 columns
  # ngrid: number of points in the grid
  # rangeObs: vector indicating the range of observations
  # alpha: parameter of the adaptive kernel
  # weightsObs: weights of observations
  # limDensity: check numerical problem
  # alpha: parameter for h.weights
  # smoothMethod: the type of smoothing I apply (default all covariance is used)
  # h.norm.x.pilot: bandwidth of pilot estimate
  # h.norm.marg.density.joint.density: bandwidth of marginal density 
  # provide.h: bandwidth is passed to the routine
  # provide.lambda: h.weights are passed to the routine
  # method.h: method to compute the bandwidth
 
library(expm)
 
 ######################################################################################
 ## Definition of stochastic kernel following Silverman (1986) p. 86-87
 ######################################################################################
  	
   normKernelBiv <- function(y,x,
		  lambdas=rep(1,dim(x)[1]),
		  invS=solve(cov(x)),
		  detS=det(cov(x)),
		  weiNorm=rep(1,dim(x)[1]),
		  h.bandwidth=h.select(x=x,weights=rep(1,dim(x)[1]),nbins=0,method="normal")){
		  
		  matrixMult <- function(M,invS){
		    uu <- matrix(M,1,2)%*%invS%*%matrix(M,2,1)
		    return(uu)
		  }
  
		  nrowX <- nrow(x)	
		  ncolX <- ncol(x)
		  eee <- (matrix(rep(y,nrowX),nrowX,ncolX,byrow=TRUE)-x)/lambdas
		  u <- eee/matrix(h.bandwidth,nrow=nrowX,ncol=2,byrow=TRUE)
		  uu <- apply(u,1,FUN=matrixMult,invS=invS)
		  fx <- (detS)^(-1/2)/(nrowX*prod(h.bandwidth))*(2*pi)^(-1)*sum(exp(-1/2*uu)*weiNorm*(lambdas^(-2)))
		  return(fx)
           }
                  
   epaKernelBiv <- function(y,x,
		  lambdas=rep(1,dim(x)[1]),
		  invS=solve(cov(x)),
		  detS=det(cov(x)),
		  weiNorm=rep(1,dim(x)[1])){
		  
		  matrixMult <- function(k,invS){
            uu <- matrix(k,1,2)%*%invS%*%matrix(k,2,1)
		    return(uu)
          }
                   nrowX <- nrow(x)	
                   ncolX <- ncol(x)
                   h.bandwidth <- c(1.77*nrowX^(-1/6),1.77*nrowX^(-1/6))
                   eee <- (matrix(rep(y,nrowX),nrowX,ncolX,byrow=TRUE)-x)/lambdas
                   u <- eee/matrix(h.bandwidth,nrow=nrow(eee),ncol=2,byrow=TRUE)
                   uu <- apply(u,1,FUN=matrixMult,invS=invS)
                   fx <- (detS)^(-1/2)/(nrowX*prod(h.bandwidth))*(2*pi)^(-1)*sum(exp(-1/2*uu[u<1])*weightsObsNorm[u<1]*(lambdas[u<1]^(-2)))
                   return(fx)
                }                    
  
  ##Normalization of weights
  weightsObsNorm <- weightsObs/mean(weightsObs)

  ##Number of observations
  n <- dim(x)[1]

  ##Alternative methods suggested in Wand and Jones, JASA 1993, p. 520,
  ##taking h=hNorm and setting the smoothing term by covariance matrix
  ##(optimal in the case of bivariate Gaussian distribution)

  if (smoothMethod=="C1"){
    ##Just one smoothing parameter
    S <- matrix(0,2,2)
    S[1,1] <- 1
    S[2,2] <- 1
  }

  if (smoothMethod=="C2"){
    ##Two smoothing parameters
    S[1,2] <- 0
    S[2,1] <- 0
  }

  if (smoothMethod=="C3"){
    ##Three smoothing parameters
    S <- S
  }

  ##Determinant and inverse of covariance matrix
  detS <- det(S)
  invS <- solve(S)

  ###################################
  ## Calculation of lambdas from the density pilot

    ##Pilot estimate, Silverman (1986), p. 101, using optimal normal bandwidth
    if(provide.h==FALSE){
      h.norm.x <- c(0.96*nrow(x)^(-1/6),0.96*nrow(x)^(-1/6))
    }else{
      h.norm.x <- h.norm.x.pilot
    } 
    
    if(provide.lambda==FALSE){
    
    	if(kernelType=="Gaussian"){
    		densityPilot <- foreach(i=1:nrow(x), .combine=c,.verbose=FALSE) %dopar%{  
				normKernelBiv(x[i,],x=x,invS=invS,detS=detS,weiNorm=weightsObsNorm, h.bandwidth=h.norm.x)
    		}
    	}
    
		if(kernelType=="Epanechnikov"){
    		densityPilot <- foreach(i=1:nrow(x), .combine=c,.verbose=FALSE) %dopar%{  
				epaKernelBiv(x[i,],x=x,invS=invS,detS=detS,weiNorm=weightsObsNorm)
    		}
    	}
       
    	lambdas <- (densityPilot/exp(mean(weightsObsNorm*log(densityPilot))))^(-alpha)
    
    }else{
        densityPilot <- NA
        lambdas <- lambdas.provide
    }
 
 
  ########################################## 
  ## The estimate of the stochastic kernel

  evalPoints.x <- new.evalPoints.x
  evalPoints.y <- seq(rangeObs.y[1],rangeObs.y[2],length=ngrid)
 
  ##Evaluation points for the stochastic kernel in 2-column format
  evalPoints_Stack <- matrix(NA,nrow=ngrid*ngrid,ncol=2)
  for (i in 1:ngrid){
    evalPoints_Stack[(1+(i-1)*ngrid):(i*ngrid),] <- cbind(rep(evalPoints.x[i],ngrid),evalPoints.y)
  }
  
  ##Gaussian kernel	
  if(kernelType=="Gaussian"){
  	
    estimateDensity_Stack <- foreach(j=1:(ngrid*ngrid), .combine=c,.verbose=FALSE) %dopar%{
  	 
       normKernelBiv(evalPoints_Stack[j,],x=x,invS=invS,detS=detS,weiNorm=weightsObsNorm, h.bandwidth=h.norm.x,lambdas=lambdas)
	  
    }
	 
  }

  ##Epanechnikov kernel
  if(kernelType=="Epanechnikov"){
  
    estimateDensity_Stack <- foreach(j=1:(ngrid*ngrid), .combine=c,.verbose=FALSE) %dopar%{
    
      epaKernelBiv(evalPoints_Stack[j,],x=x,invS=invS,detS=detS,weiNorm=weightsObsNorm,lambdas=lambdas)  
    
    }
 
 }  
 
 ##Estimation of density in matrix (ngrid x ngrid) format
 estimateDensity <- matrix(NA, nrow=ngrid, ncol=ngrid)
 for (i in 1:ngrid){
   estimateDensity[i,] <- estimateDensity_Stack[(1+(i-1)*ngrid):(i*ngrid)] 
 }
 
 ##Marginal density
  margDensity <- univariateDensityAdaptive_Parallel(u=x[,2],
                             provide.h=provide.h,
                             h.u.pilot=h.norm.marg.density,
                             figure=FALSE,ngrid=ngrid,weightsObs=weightsObsNorm,
                             alpha=alpha,provide.eval.points=TRUE,
                             eval.points.provide=evalPoints.y,
                             kernelType=kernelType,method.h=method.h)

  margDensityEstimate <- margDensity$estimate

  ##Check for the computation of kernel at the bounds of range
  ini <- 1
  fin <- ngrid
 
 ##Check for the limit density
  estimateDensity[estimateDensity<limDensity] <-0

 ## ATTENTION: The most efficient way is not to use non parallel computation here
    ##Rough stochastic kernel
    stocKernelNotAdj <- foreach(j = ini:fin, .combine=cbind) %do% {
    	estimateDensity[,j]/margDensityEstimate[j]
    }
     ##Adjusted stochastic kernel to check for the condition that the integration of conditional density is equal to 1
    stocKernel <- foreach(j = ini:fin, .combine=cbind) %do% {
    	stocKernelNotAdj[,j]/numericalIntegration(stocKernelNotAdj[,j],evalPoints.x,checkTail=TRUE)$fdensity
    }

#####################################################################################    
## Calculate the mode, the median and the expected value of the stochastic kernel
 
 maxKernel <- vector(mode="numeric",length=(fin-ini+1))

 medianKernelNotAdj <- vector(mode="numeric",length=(fin-ini+1))
 medianKernel <- vector(mode="numeric",length=(fin-ini+1))

 averageKernelNotAdj <- vector(mode="numeric",length=(fin-ini+1))
 averageKernel <- vector(mode="numeric",length=(fin-ini+1))

 gap <- diff(evalPoints.x)
 
 for(i in ini:fin){

    ## Conditional median of not adjusted kernel
   j <- 1
    area.k <- stocKernelNotAdj[1,i]*gap[j]/2
    while(area.k<=0.5 & j<ngrid){ 
      area.k <- area.k + (stocKernelNotAdj[(j+1),i]+stocKernelNotAdj[j,i])*gap[j]/2
      j<-j+1
    }
    medianKernelNotAdj[i] <-  evalPoints.x[j]
   
   ## Conditional expected value of not adjusted kernel
   averageKernelNotAdj[i] <- numericalIntegration(stocKernelNotAdj[,i], evalPoints.x)$average 
 
   ## Conditional mode of kernel
   iii <- max(stocKernel[,i])==stocKernel[,i]
   maxKernel[i] <- evalPoints.x[iii][1]
 
   ## Conditional median
   j <- 1
   area.k <- stocKernel[1,i]*gap[j]/2
   while(area.k<=0.5 & j<ngrid){
     area.k <- area.k + (stocKernel[(j+1),i]+stocKernel[j,i])*gap[j]/2
     j<-j+1
   }
   medianKernel[i] <-  evalPoints.x[j]
    
   ##Conditional expected value
   averageKernel[i] <- numericalIntegration(stocKernel[,i], evalPoints.x)$average 
    
 }

########################## 
## Ergodic distribution
    ergoDistr <- NA
    ergoDistrNorm <- NA
    evalPointsNorm.x <- NA
    gap <- diff(margDensity$eval.points)[1]
   
    if (ergodicDistr==TRUE){ 		
    	P1 <- stocKernel*gap[1]
    	numStates <- dim(P1)[1]
    	
    	 ## ATTENTION: The most efficient way is to use non parallel computation here
    	P1M <- foreach(l = ini:fin, .combine=cbind) %do% {		
	    P1[,l]/sum(P1[,l])
         }

	P1MErgo <- P1M%^%400
	ergoDistr <- P1MErgo[,1]/gap
    	
	#Correction if variable should have mean equal to 1
	if(obsNormalized==TRUE){  		
	  ergoDistrNorm <- ergoDistr*numericalIntegration(ergoDistr, evalPoints.x)$average
	  evalPointsNorm.x <- evalPoints.x/numericalIntegration(ergoDistr, evalPoints.x)$average
	}
    
  }
    

########################################################àà
## Picture of stochastic kernel
  if(figure==TRUE){
    dev.new()
    split.screen(c(1,3))
    screen(1)
    contour(evalPoints.x, evalPoints.y,estimateDensity,nlevel=20,
      main="Joint density estimate",xlab="Future obs",ylab="Current obs")
    lines(c(evalPoints.x[1],evalPoints.x[ngrid]),c(evalPoints.y[1],evalPoints.y[ngrid]),
      lwd=2,col="red")
    screen(2)
    plot(evalPoints.x,margDensityEstimate,type="l",main="Marginal and ergodic density estimates")
    lines(evalPoints.x,ergoDistr,col="red")
    screen(3)
    iii <- evalPoints.x>=rangeObs.x[1] & evalPoints.x<=rangeObs.x[2]
    contour(evalPoints.x[iii],evalPoints.y[iii],
            stocKernel[iii,iii],nlevels=15,
            xlim=rangeObs.x,ylim=rangeObs.y,
            labcex = 0.6,
            xlab="x(t+1)",
            ylab="x(t)",lwd=0.5)
    grid(nx=15,ny=15,col="black")
    #Plot Observations
    points(x[,1],x[,2],lwd=1,col="red",cex=0.2)    
    #Plot the limits of classes
    lines(rangeObs.x,rangeObs.y,lwd=2)
    #Plot the median of conditional distribution
    lines(medianKernel[iii],evalPoints.y[iii],lwd=4,col="black",lty=1)
    lines(maxKernel[iii],evalPoints.y[iii],lwd=2,col="blue",lty=3)

	# dev.new()
	# iii <- evalPoints>=rangeObs[1] & evalPoints<=rangeObs[2]
    # contour(evalPoints[iii],evalPoints[iii],
            # stocKernel[iii,iii],nlevels=15,
            # xlim=rangeObs,ylim=rangeObs,
            # labcex = 0.6,
            # xlab="x(t+1)",
            # ylab="x(t)",lwd=0.2)
    # contour(evalPoints[iii],evalPoints[iii],
            # stocKernelNotAdj[iii,iii],nlevels=15,
            # xlim=rangeObs,ylim=rangeObs,
            # labcex = 0.6,lwd=0.7,add=TRUE,col="red")        
    # grid(nx=15,ny=15,col="black")
    # #Plot Observations
    # points(x[,1],x[,2],lwd=1,col="red",cex=0.2)    
    # #Plot the limits of classes
    # lines(rangeObs,rangeObs,lwd=2)
    # #Plot the median of conditional distribution
    # lines(medianKernelNotAdj[iii],evalPoints[iii],lwd=4,col="red",lty=1)
    # lines(medianKernel[iii],evalPoints[iii],lwd=4,col="black",lty=1)
    # lines(maxKernel[iii],evalPoints[iii],lwd=2,col="blue",lty=3)

  }
 
 list(S=S,estimateDensity=estimateDensity,evalPoints.x=evalPoints.x,evalPoints.y=evalPoints.y,stocKernel=stocKernel,
   maxKernel=maxKernel,medianKernel=medianKernel,margDensityEstimate=margDensityEstimate,
   weightsObsNorm=weightsObsNorm,
   h.norm.x=h.norm.x,h.norm.marg.density=margDensity$h.u,
   lambdas=lambdas,x=x,
   densityPilot=densityPilot,
   medianKernelNotAdj=medianKernelNotAdj,
   stocKernelNotAdj=stocKernelNotAdj,
   ergoDistr=ergoDistr,
   ergoDistrNorm=ergoDistrNorm,
   evalPointsNorm.x=evalPointsNorm.x,
   averageKernel=averageKernel,
   averageKernelNotAdj=averageKernelNotAdj
   )
 
 }
