####################################################
#
# Davide Fiaschi, Lisa Gianmoena, and Angela Parenti
#
# Last update 05/11/2019
# 
####################################################

#******************************************************************************************
# what we do:
# - creation of the dataset at NUTS2 level for our set of regions of all the varaibile of the CE2019 in real terms (base 2005) and in PPP
# To do that we consider the dataset of Cambridge Economentrics version 2016, (Last revised: 2017) 
# and the dataset real.PPP.GDP.GVA.Compensation.of.Employees.RData which contains data in PPP

# [lines 636-789] creation of Spatial Matrix based on first and second contiguity; countries matrix; with cut-off and inverse distance squared; with elements proportional to the K-nearest neighbours
#*******************************************************************************************


#Remove any object
rm(list=ls(all=TRUE))

#Library
library(mgcv)
library(sm)
library(plm)
library(foreach)
library(doMC)
registerDoMC(12)

#Load Cambridge Econometrics dataset
load("cambridgeEconometrics_2016_18_10.RData")
load("real.PPP.GDP.GVA.Compensation.of.Employees.RData")

#Years of analysis
years <- 1992:2015

#NUTS 2 in our sample
code.NUTS <-  substr( rownames(real.PPP.Total.CompensationEmployees),start=1,stop=4)
only.NUTS2 <- nchar(code.NUTS)==4
code.NUTS2.our.sample <- code.NUTS[only.NUTS2]

#Remove some "unluck" NUTS-2 regions
code.NUTS2.our.sample <- code.NUTS2.our.sample[c(-which(code.NUTS2.our.sample=="MT00"), #Malta
                                                 -which(code.NUTS2.our.sample=="ES63"), #Ceuta
                                                 -which(code.NUTS2.our.sample=="ES64"), #Melilla
                                                 -which(code.NUTS2.our.sample=="ES64"), #Canaries
                                                 -which(code.NUTS2.our.sample=="FRY1"), #Guadeloupe
                                                 -which(code.NUTS2.our.sample=="FRY2"), #Martinique
                                                 -which(code.NUTS2.our.sample=="FRY3"), #French Guiana
                                                 -which(code.NUTS2.our.sample=="FRY4"), #La Réunion
                                                 -which(code.NUTS2.our.sample=="FRY5"), #Mayotte
                                                 -which(code.NUTS2.our.sample=="PT20"), #Azores 
                                                 -which(code.NUTS2.our.sample=="PT30") #Madeira
                                                 )]


#=========================
#Total employment (in 000)
#=========================

# Reoder with the correct NUTS2 rank the rownames of the varaibles (nb: we add at the end new regions)
# the jjj and the kkk can be used for the employment variables
jjj <- rownames(Employment$Total)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$Total)[jjj])
#cbind( rownames(Employment$Total)[jjj][kkk],code.NUTS2.our.sample)
tot.employment.NUTS2  <- Employment$Total[jjj,colnames(Employment$Total)%in%years][kkk,]
rownames(tot.employment.NUTS2) <- code.NUTS2.our.sample
colnames(tot.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,tot.employment.NUTS2[,1])

#=========================
# Total Compensation
#=========================

 jjj <- rownames(real.PPP.Total.CompensationEmployees)%in%code.NUTS2.our.sample
 kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Total.CompensationEmployees)[jjj])
 #cbind(rownames(real.PPP.Total.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)

 tot.compensation.of.employee.NUTS2.real.PPP <- real.PPP.Total.CompensationEmployees[jjj,colnames(real.PPP.Total.CompensationEmployees)%in%years][kkk,]
 rownames(tot.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
 colnames(tot.compensation.of.employee.NUTS2.real.PPP) <- years
 #cbind(code.NUTS2.our.sample,tot.compensation.of.employee.NUTS2.real.PPP[,1])

# Level of compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
tot.compensation.per.employee.NUTS2.real.PPP <- (tot.compensation.of.employee.NUTS2.real.PPP/tot.employment.NUTS2)*1000000/1000
#cbind(code.NUTS2.our.sample,tot.compensation.per.employee.NUTS2.real.PPP[,1])
                                           
#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.tot.compensation.per.employee.NUTS2.real.PPP <- tot.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(tot.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(tot.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(tot.compensation.per.employee.NUTS2.real.PPP),byrow=T)

# compensation per employees growth rates
tot.compensation.per.employee.GR.NUTS2.real.PPP <- matrix(NA,dim(tot.compensation.per.employee.NUTS2.real.PPP)[1],(dim(tot.compensation.per.employee.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(tot.compensation.per.employee.NUTS2.real.PPP)[2]-1)){
  tot.compensation.per.employee.GR.NUTS2.real.PPP[,j] <- (tot.compensation.per.employee.NUTS2.real.PPP[,j+1]-tot.compensation.per.employee.NUTS2.real.PPP[,j])/tot.compensation.per.employee.NUTS2.real.PPP[,j]
}
rownames(tot.compensation.per.employee.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(tot.compensation.per.employee.GR.NUTS2.real.PPP) <- years[-1]

# Average of Compensation per employee growth rates
tot.compensation.per.employee.GR.NUTS2.real.PPP.AvSample <- colMeans(tot.compensation.per.employee.GR.NUTS2.real.PPP, na.rm=TRUE)

#=========================
# Sectoral Compensation
#=========================
#=============
# Agriculture: compensation in real terms (base 2005) in PPP
#=============

# Employment in agriculture (in 000)
jjj <- rownames(Employment$Agriculture)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$Agriculture)[jjj])
#cbind( rownames(Employment$Agriculture)[jjj][kkk],code.NUTS2.our.sample)
agri.employment.NUTS2  <- Employment$Agriculture[jjj,colnames(Employment$Agriculture)%in%years][kkk,]
rownames(agri.employment.NUTS2) <- code.NUTS2.our.sample
colnames(agri.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,agri.employment.NUTS2[,1])

# Real PPP total compensation OF employee in agriculture (€2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.Agriculture.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Agriculture.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.Agriculture.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
agri.compensation.of.employee.NUTS2.real.PPP <- real.PPP.Agriculture.CompensationEmployees[jjj,colnames(real.PPP.Agriculture.CompensationEmployees)%in%years][kkk,]
rownames(agri.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(agri.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,agri.compensation.of.employee.NUTS2.real.PPP[,1])

# control for the inf (  we have problem with some regions that have not compensation but have employment....so so wierd!!! as ceuta e Melilla) (no anymore becouse we remove from the sample)
#agri.compensation.per.employee.NUTS2.real.PPP[mapply(is.infinite, agri.compensation.per.employee.NUTS2.real.PPP)] <- NA

# Real PPP total compensation PER employee in agriculture (€2005m) and in PPP (EU28=1)
agri.compensation.per.employee.NUTS2.real.PPP <- (agri.compensation.of.employee.NUTS2.real.PPP/tot.employment.NUTS2)*1000000/1000
#cbind(code.NUTS2.our.sample,tot.compensation.per.employee.NUTS2.real.PPP[,1])

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.agri.compensation.per.employee.NUTS2.real.PPP <- agri.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(agri.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(agri.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(agri.compensation.per.employee.NUTS2.real.PPP),byrow=T)

#==========
# Industry
#==========

# Employment in industry (in 000, Thousands of people) 
jjj <- rownames(Employment$Industry)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$Industry)[jjj])
#cbind( rownames(Employment$Industry)[jjj][kkk],code.NUTS2.our.sample)
industry.employment.NUTS2  <- Employment$Industry[jjj,colnames(Employment$Industry)%in%years][kkk,]
rownames(industry.employment.NUTS2) <- code.NUTS2.our.sample
colnames(industry.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,industry.employment.NUTS2[,1])

# Real PPP total compensation OF employee in industry (Millions of Euro in 2005 prices €2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.Industry.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Industry.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.Industry.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
industry.compensation.of.employee.NUTS2.real.PPP <- real.PPP.Industry.CompensationEmployees[jjj,colnames(real.PPP.Industry.CompensationEmployees)%in%years][kkk,]
rownames(industry.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(industry.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,industry.compensation.of.employee.NUTS2.real.PPP[,1])

# Real PPP total compensation PER employee in industry and in PPP (EU28=1)
industry.compensation.per.employee.NUTS2.real.PPP <- (industry.compensation.of.employee.NUTS2.real.PPP/industry.employment.NUTS2)*1000000/1000

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.industry.compensation.per.employee.NUTS2.real.PPP <- industry.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(industry.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(industry.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(industry.compensation.per.employee.NUTS2.real.PPP),byrow=T)

#===============
# Construction: compensation in real terms (base 2005) in PPP
#===============

# Employment in construction (in 000)
jjj <- rownames(Employment$Construction)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$Construction)[jjj])
#cbind( rownames(Employment$Construction)[jjj][kkk],code.NUTS2.our.sample)
constr.employment.NUTS2  <- Employment$Construction[jjj,colnames(Employment$Construction)%in%years][kkk,]
rownames(constr.employment.NUTS2) <- code.NUTS2.our.sample
colnames(constr.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,constr.employment.NUTS2[,1])

# Real PPP total compensation OF employee in industry (Millions of Euro in 2005 prices €2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.Construction.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Construction.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.Construction.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
constr.compensation.of.employee.NUTS2.real.PPP <- real.PPP.Construction.CompensationEmployees[jjj,colnames(real.PPP.Construction.CompensationEmployees)%in%years][kkk,]
rownames(constr.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(constr.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,constr.compensation.of.employee.NUTS2.real.PPP[,1])

# Real PPP total compensation PER employee in industry and in PPP (EU28=1)
constr.compensation.per.employee.NUTS2.real.PPP <- (constr.compensation.of.employee.NUTS2.real.PPP/constr.employment.NUTS2)*1000000/1000

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.constr.compensation.per.employee.NUTS2.real.PPP <- constr.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(constr.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(constr.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(constr.compensation.per.employee.NUTS2.real.PPP),byrow=T)


#=========
# WRTAFIC: compensation in real terms (base 2005) in PPP
#=========

# Employment in WRTAFIC (in 000, Thousands of people) 
jjj <- rownames(Employment$WRTAFIC)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$WRTAFIC)[jjj])
#cbind( rownames(Employment$WRTAFIC)[jjj][kkk],code.NUTS2.our.sample)
WRTAFIC.employment.NUTS2  <- Employment$WRTAFIC[jjj,colnames(Employment$WRTAFIC)%in%years][kkk,]
rownames(WRTAFIC.employment.NUTS2) <- code.NUTS2.our.sample
colnames(WRTAFIC.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,WRTAFIC.employment.NUTS2[,1])

# Real PPP total compensation OF employee in industry (Millions of Euro in 2005 prices €2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.WRTAFIC.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.WRTAFIC.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.WRTAFIC.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
WRTAFIC.compensation.of.employee.NUTS2.real.PPP <- real.PPP.WRTAFIC.CompensationEmployees[jjj,colnames(real.PPP.WRTAFIC.CompensationEmployees)%in%years][kkk,]
rownames(WRTAFIC.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(WRTAFIC.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,WRTAFIC.compensation.of.employee.NUTS2.real.PPP[,1])

# Real PPP total compensation PER employee in industry and in PPP (EU28=1)
WRTAFIC.compensation.per.employee.NUTS2.real.PPP <- (WRTAFIC.compensation.of.employee.NUTS2.real.PPP/WRTAFIC.employment.NUTS2)*1000000/1000

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.WRTAFIC.compensation.per.employee.NUTS2.real.PPP <- WRTAFIC.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(WRTAFIC.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(WRTAFIC.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(WRTAFIC.compensation.per.employee.NUTS2.real.PPP),byrow=T)

#======
# FBS: compensation in real terms (base 2005) in PPP
#======

# Employment in FBS (in 000, Thousands of people) 
jjj <- rownames(Employment$Industry)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$FBS)[jjj])
#cbind( rownames(Employment$FBS)[jjj][kkk],code.NUTS2.our.sample)
FBS.employment.NUTS2  <- Employment$FBS[jjj,colnames(Employment$FBS)%in%years][kkk,]
rownames(FBS.employment.NUTS2) <- code.NUTS2.our.sample
colnames(FBS.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,FBS.employment.NUTS2[,1])


# Real PPP total compensation of employee in FBS (Millions of Euro in 2005 prices €2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.FBS.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.FBS.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.FBS.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
FBS.compensation.of.employee.NUTS2.real.PPP <- real.PPP.FBS.CompensationEmployees[jjj,colnames(real.PPP.FBS.CompensationEmployees)%in%years][kkk,]
rownames(FBS.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(FBS.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,FBS.compensation.of.employee.NUTS2.real.PPP[,1])

# Real PPP total compensation PER employee in industry and in PPP (EU28=1)
FBS.compensation.per.employee.NUTS2.real.PPP <- (FBS.compensation.of.employee.NUTS2.real.PPP/FBS.employment.NUTS2)*1000000/1000

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.FBS.compensation.per.employee.NUTS2.real.PPP <- FBS.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(FBS.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(FBS.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(FBS.compensation.per.employee.NUTS2.real.PPP),byrow=T)

#======
# NMS: compensation in real terms (base 2005) in PPP
#======
# Employment in NMS (in 000, Thousands of people) 
jjj <- rownames(Employment$`Non-Market Services`)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(Employment$`Non-Market Services`)[jjj])
#cbind( rownames(Employment$`Non-Market Services`)[jjj][kkk],code.NUTS2.our.sample)
NMS.employment.NUTS2  <- Employment$`Non-Market Services`[jjj,colnames(Employment$`Non-Market Services`)%in%years][kkk,]
rownames(NMS.employment.NUTS2) <- code.NUTS2.our.sample
colnames(NMS.employment.NUTS2) <- years
# cbind(code.NUTS2.our.sample,NMS.employment.NUTS2[,1])

# Real PPP total compensation OF employee in NMS (Millions of Euro in 2005 prices €2005m) and in PPP (EU28=1)
jjj <- rownames(real.PPP.NMS.CompensationEmployees)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.NMS.CompensationEmployees)[jjj])
#cbind(rownames(real.PPP.NMS.CompensationEmployees)[jjj][kkk],code.NUTS2.our.sample)
NMS.compensation.of.employee.NUTS2.real.PPP <- real.PPP.NMS.CompensationEmployees[jjj,colnames(real.PPP.NMS.CompensationEmployees)%in%years][kkk,]
rownames(NMS.compensation.of.employee.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(NMS.compensation.of.employee.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,NMS.compensation.of.employee.NUTS2.real.PPP[,1])

# Real PPP total compensation PER employee in NMS and in PPP (EU28=1)
NMS.compensation.per.employee.NUTS2.real.PPP <- (NMS.compensation.of.employee.NUTS2.real.PPP/NMS.employment.NUTS2)*1000000/1000

#Relative to sample average compensation per employees in real Euro (base 2005) and in PPP (EU28=1)
rel.NMS.compensation.per.employee.NUTS2.real.PPP <- NMS.compensation.per.employee.NUTS2.real.PPP/matrix(colMeans(NMS.compensation.per.employee.NUTS2.real.PPP,na.rm=T),ncol=ncol(NMS.compensation.per.employee.NUTS2.real.PPP),nrow=nrow(NMS.compensation.per.employee.NUTS2.real.PPP),byrow=T)


#============
# GVA in PPP
#============
# Total GVA in Millions of Euro in 2005 prices (€2005m) in PPP 
jjj <- rownames(real.PPP.Total.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Total.GVA)[jjj])
#cbind(rownames(real.PPP.Total.GVA)[jjj][kkk],code.NUTS2.our.sample)
GVA.NUTS2.real.PPP <- real.PPP.Total.GVA[jjj,colnames(real.PPP.Total.GVA)%in%years][kkk,]
rownames(GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(GVA.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,GVA.NUTS2.real.PPP[,1])

# GVA in (€2005m) in PPP  per worker
GVA.per.worker.NUTS2.real.PPP <- (GVA.NUTS2.real.PPP/tot.employment.NUTS2)*1000000/1000

#Relative to sample average GVA per worker in (€2005m) in PPP
rel.GVA.per.worker.NUTS2.real.PPP <- GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(GVA.per.worker.NUTS2.real.PPP),nrow=nrow(GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA per worker growth rates
GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(GVA.per.worker.NUTS2.real.PPP)[1],(dim(GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (GVA.per.worker.NUTS2.real.PPP[,j+1]-GVA.per.worker.NUTS2.real.PPP[,j])/GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of GVA per worker growth rates
GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

#===============================================
# Sectoral GVA Millions of Euro in 2005 prices (€2005m) in PPP 
#================================================
#=============
# Agriculture: GVA in real terms (base 2005) in PPP
#=============
jjj <- rownames(real.PPP.Agriculture.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Agriculture.GVA)[jjj])
#cbind(rownames(real.PPP.Agriculture.GVA)[jjj][kkk],code.NUTS2.our.sample)
agri.GVA.NUTS2.real.PPP <- real.PPP.Agriculture.GVA[jjj,colnames(real.PPP.Agriculture.GVA)%in%years][kkk,]
rownames(agri.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(agri.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,agri.GVA.NUTS2.real.PPP[,1])

# GVA agriculture in  (€2005m) in PPP  per worker
agri.GVA.per.worker.NUTS2.real.PPP <- (agri.GVA.NUTS2.real.PPP/agri.employment.NUTS2)*1000000/1000

# control for the inf (becouse we have problem with some regions that have not compensation but have employment....so so wierd!!!)
agri.GVA.per.worker.NUTS2.real.PPP[mapply(is.infinite, agri.GVA.per.worker.NUTS2.real.PPP)] <- NA

#Relative to sample average GVA agriculture per worker in (€2005m) in PPP
rel.agri.GVA.per.worker.NUTS2.real.PPP <- agri.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(agri.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(agri.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(agri.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA agriculture per worker growth rates
agri.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(agri.GVA.per.worker.NUTS2.real.PPP)[1],(dim(agri.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(agri.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  agri.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (agri.GVA.per.worker.NUTS2.real.PPP[,j+1]-agri.GVA.per.worker.NUTS2.real.PPP[,j])/agri.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(agri.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(agri.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of agriculture GVA per worker growth rates
agri.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(agri.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

#=========
# Industry: GVA in real terms (base 2005) in PPP
#=========
jjj <- rownames(real.PPP.Industry.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Industry.GVA)[jjj])
#cbind(rownames(real.PPP.Industry.GVA)[jjj][kkk],code.NUTS2.our.sample)
industry.GVA.NUTS2.real.PPP <- real.PPP.Industry.GVA[jjj,colnames(real.PPP.Industry.GVA)%in%years][kkk,]
rownames(industry.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(industry.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,industry.GVA.NUTS2.real.PPP[,1])

# GVA industry in  (€2005m) in PPP  per worker
industry.GVA.per.worker.NUTS2.real.PPP <- (industry.GVA.NUTS2.real.PPP/industry.employment.NUTS2)*1000000/1000

#Relative to sample average GVA industry per worker in (€2005m) in PPP
rel.industry.GVA.per.worker.NUTS2.real.PPP <- industry.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(industry.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(industry.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(industry.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA industry per worker growth rates
industry.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(industry.GVA.per.worker.NUTS2.real.PPP)[1],(dim(industry.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(industry.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  industry.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (industry.GVA.per.worker.NUTS2.real.PPP[,j+1]-industry.GVA.per.worker.NUTS2.real.PPP[,j])/industry.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(industry.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(industry.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of industry GVA per worker growth rates
industry.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(industry.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

#=========
# Construction: GVA in real terms (base 2005) in PPP
#=========
jjj <- rownames(real.PPP.Construction.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.Construction.GVA)[jjj])
#cbind(rownames(real.PPP.Construction.GVA)[jjj][kkk],code.NUTS2.our.sample)
constr.GVA.NUTS2.real.PPP <- real.PPP.Construction.GVA[jjj,colnames(real.PPP.Construction.GVA)%in%years][kkk,]
rownames(constr.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(constr.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,constr.GVA.NUTS2.real.PPP[,1])

# GVA construction in  (€2005m) in PPP  per worker
constr.GVA.per.worker.NUTS2.real.PPP <- (constr.GVA.NUTS2.real.PPP/constr.employment.NUTS2)*1000000/1000

#Relative to sample average GVA construction per worker in (€2005m) in PPP
rel.constr.GVA.per.worker.NUTS2.real.PPP <- constr.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(constr.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(constr.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(constr.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA construction per worker growth rates
constr.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(constr.GVA.per.worker.NUTS2.real.PPP)[1],(dim(constr.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(constr.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  constr.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (constr.GVA.per.worker.NUTS2.real.PPP[,j+1]-constr.GVA.per.worker.NUTS2.real.PPP[,j])/constr.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(constr.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(constr.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of construction GVA per worker growth rates
constr.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(constr.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

#=========
# WRTAFIC: GVA in real terms (base 2005) in PPP
#=========
jjj <- rownames(real.PPP.WRTAFIC.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.WRTAFIC.GVA)[jjj])
#cbind(rownames(real.PPP.WRTAFIC.GVA)[jjj][kkk],code.NUTS2.our.sample)
WRTAFIC.GVA.NUTS2.real.PPP <- real.PPP.WRTAFIC.GVA[jjj,colnames(real.PPP.WRTAFIC.GVA)%in%years][kkk,]
rownames(WRTAFIC.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(WRTAFIC.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,WRTAFIC.GVA.NUTS2.real.PPP[,1])

# GVA WRTAFIC in  (€2005m) in PPP  per worker
WRTAFIC.GVA.per.worker.NUTS2.real.PPP <- (WRTAFIC.GVA.NUTS2.real.PPP/WRTAFIC.employment.NUTS2)*1000000/1000

#Relative to sample average GVA WRTAFIC per worker in (€2005m) in PPP
rel.WRTAFIC.GVA.per.worker.NUTS2.real.PPP <- WRTAFIC.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(WRTAFIC.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(WRTAFIC.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(WRTAFIC.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA WRTAFIC per worker growth rates
WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(WRTAFIC.GVA.per.worker.NUTS2.real.PPP)[1],(dim(WRTAFIC.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(WRTAFIC.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (WRTAFIC.GVA.per.worker.NUTS2.real.PPP[,j+1]-WRTAFIC.GVA.per.worker.NUTS2.real.PPP[,j])/WRTAFIC.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of WRTAFIC GVA per worker growth rates
WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)


#=========
# FBS: GVA in real terms (base 2005) in PPP
#=========
jjj <- rownames(real.PPP.FBS.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.FBS.GVA)[jjj])
#cbind(rownames(real.PPP.FBS.GVA)[jjj][kkk],code.NUTS2.our.sample)
FBS.GVA.NUTS2.real.PPP <- real.PPP.FBS.GVA[jjj,colnames(real.PPP.FBS.GVA)%in%years][kkk,]
rownames(FBS.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(FBS.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,FBS.GVA.NUTS2.real.PPP[,1])

# GVA FBS in  (€2005m) in PPP  per worker
FBS.GVA.per.worker.NUTS2.real.PPP <- (FBS.GVA.NUTS2.real.PPP/FBS.employment.NUTS2)*1000000/1000

#Relative to sample average GVA FBS per worker in (€2005m) in PPP
rel.FBS.GVA.per.worker.NUTS2.real.PPP <- FBS.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(FBS.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(FBS.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(FBS.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA FBS per worker growth rates
FBS.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(FBS.GVA.per.worker.NUTS2.real.PPP)[1],(dim(FBS.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(FBS.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  FBS.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (FBS.GVA.per.worker.NUTS2.real.PPP[,j+1]-FBS.GVA.per.worker.NUTS2.real.PPP[,j])/FBS.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(FBS.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(FBS.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of FBS GVA per worker growth rates
FBS.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(FBS.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

#=========
# NMS: GVA in real terms (base 2005) in PPP
#=========
jjj <- rownames(real.PPP.NMS.GVA)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.NMS.GVA)[jjj])
#cbind(rownames(real.PPP.NMS.GVA)[jjj][kkk],code.NUTS2.our.sample)
NMS.GVA.NUTS2.real.PPP <- real.PPP.NMS.GVA[jjj,colnames(real.PPP.NMS.GVA)%in%years][kkk,]
rownames(NMS.GVA.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(NMS.GVA.NUTS2.real.PPP) <- years
# cbind(code.NUTS2.our.sample,NMS.GVA.NUTS2.real.PPP[,1])

# GVA NMS in  (€2005m) in PPP  per worker
NMS.GVA.per.worker.NUTS2.real.PPP <- (NMS.GVA.NUTS2.real.PPP/NMS.employment.NUTS2)*1000000/1000

#Relative to sample average GVA NMS per worker in (€2005m) in PPP
rel.NMS.GVA.per.worker.NUTS2.real.PPP <- NMS.GVA.per.worker.NUTS2.real.PPP/matrix(colMeans(NMS.GVA.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(NMS.GVA.per.worker.NUTS2.real.PPP),nrow=nrow(NMS.GVA.per.worker.NUTS2.real.PPP),byrow=T)

# GVA NMS per worker growth rates
NMS.GVA.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(NMS.GVA.per.worker.NUTS2.real.PPP)[1],(dim(NMS.GVA.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(NMS.GVA.per.worker.NUTS2.real.PPP)[2]-1)){
  NMS.GVA.per.worker.GR.NUTS2.real.PPP[,j] <- (NMS.GVA.per.worker.NUTS2.real.PPP[,j+1]-NMS.GVA.per.worker.NUTS2.real.PPP[,j])/NMS.GVA.per.worker.NUTS2.real.PPP[,j]
}
rownames(NMS.GVA.per.worker.GR.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(NMS.GVA.per.worker.GR.NUTS2.real.PPP) <- years[-1]

# Average of NMS GVA per worker growth rates
NMS.GVA.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(NMS.GVA.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)


#=======================================================
# GDP and GDP per worker and GDP per worker growth rate in PPP
#=======================================================

# Total GDP  (GDP in billions and employment in 1000 in Cambridge Econometrics)
jjj <- rownames(real.PPP.GDP)%in%code.NUTS2.our.sample
kkk <- match(code.NUTS2.our.sample,rownames(real.PPP.GDP)[jjj])
#cbind(rownames(real.PPP.GDP)[jjj][kkk],code.NUTS2.our.sample)
GDP.NUTS2.real.PPP <- real.PPP.GDP[jjj,colnames(real.PPP.GDP)%in%years][kkk,]
rownames(GDP.NUTS2.real.PPP) <- code.NUTS2.our.sample
colnames(GDP.NUTS2.real.PPP) <- years
#cbind(code.NUTS2.our.sample,GDP.NUTS2.real.PPP[,1])

# GDP per worker
GDP.per.worker.NUTS2.real.PPP<- (GDP.NUTS2.real.PPP/tot.employment.NUTS2)*1000000000/1000

#Relative to sample average GDP per worker
rel.GDP.per.worker.NUTS2.real.PPP <- GDP.per.worker.NUTS2.real.PPP/matrix(colMeans(GDP.per.worker.NUTS2.real.PPP,na.rm=T),ncol=ncol(GDP.per.worker.NUTS2.real.PPP),nrow=nrow(GDP.per.worker.NUTS2.real.PPP),byrow=T)

# GDP per worker growth rates
GDP.per.worker.GR.NUTS2.real.PPP <- matrix(NA,dim(GDP.per.worker.NUTS2.real.PPP)[1],(dim(GDP.per.worker.NUTS2.real.PPP)[2]-1))
for (j in 1:(dim(GDP.per.worker.NUTS2.real.PPP)[2]-1)){
  GDP.per.worker.GR.NUTS2.real.PPP[,j] <- (GDP.per.worker.NUTS2.real.PPP[,j+1]-GDP.per.worker.NUTS2.real.PPP[,j])/GDP.per.worker.NUTS2.real.PPP[,j]
}

# Average of GDP per worker growth rates
GDP.per.worker.GR.NUTS2.real.PPP.AvSample <- colMeans(GDP.per.worker.GR.NUTS2.real.PPP, na.rm=TRUE)

cbind(rownames(industry.compensation.per.employee.NUTS2.real.PPP),industry.compensation.per.employee.NUTS2.real.PPP[,24])
summary(industry.compensation.per.employee.NUTS2.real.PPP[,24])

#***************************************************
# Share of total compensations of employees on GVA
#***************************************************
# total 
share.tot.compensation.on.tot.GVA <- tot.compensation.per.employee.NUTS2.real.PPP/GVA.per.worker.NUTS2.real.PPP

# agriculture
share.agri.compensation.on.tot.GVA <- agri.compensation.per.employee.NUTS2.real.PPP/agri.GVA.per.worker.NUTS2.real.PPP

# industry
share.industry.compensation.on.tot.GVA <- industry.compensation.per.employee.NUTS2.real.PPP/industry.GVA.per.worker.NUTS2.real.PPP

# construction
share.constr.compensation.on.tot.GVA <- constr.compensation.per.employee.NUTS2.real.PPP/constr.GVA.per.worker.NUTS2.real.PPP

# WRTAFIC
share.WRTAFIC.compensation.on.tot.GVA <- WRTAFIC.compensation.per.employee.NUTS2.real.PPP/WRTAFIC.GVA.per.worker.NUTS2.real.PPP

# FBS
share.FBS.compensation.on.tot.GVA <- FBS.compensation.per.employee.NUTS2.real.PPP/FBS.GVA.per.worker.NUTS2.real.PPP

# NMS
share.NMS.compensation.on.tot.GVA <- NMS.compensation.per.employee.NUTS2.real.PPP/NMS.GVA.per.worker.NUTS2.real.PPP

save(code.NUTS2.our.sample, tot.employment.NUTS2,agri.employment.NUTS2, industry.employment.NUTS2, constr.employment.NUTS2, WRTAFIC.employment.NUTS2, FBS.employment.NUTS2, NMS.employment.NUTS2,
     
     tot.compensation.of.employee.NUTS2.real.PPP,
     tot.compensation.per.employee.NUTS2.real.PPP,
     rel.tot.compensation.per.employee.NUTS2.real.PPP,
     tot.compensation.per.employee.GR.NUTS2.real.PPP,
     tot.compensation.per.employee.GR.NUTS2.real.PPP.AvSample,
     
     agri.employment.NUTS2,
     agri.compensation.of.employee.NUTS2.real.PPP,
     agri.compensation.per.employee.NUTS2.real.PPP,
     rel.agri.compensation.per.employee.NUTS2.real.PPP,
     
     industry.employment.NUTS2,
     industry.compensation.of.employee.NUTS2.real.PPP,
     industry.compensation.per.employee.NUTS2.real.PPP,
     rel.industry.compensation.per.employee.NUTS2.real.PPP,
     
     constr.employment.NUTS2,
     constr.compensation.of.employee.NUTS2.real.PPP,
     constr.compensation.per.employee.NUTS2.real.PPP,
     rel.constr.compensation.per.employee.NUTS2.real.PPP,
     
     WRTAFIC.employment.NUTS2,
     WRTAFIC.compensation.of.employee.NUTS2.real.PPP,
     WRTAFIC.compensation.per.employee.NUTS2.real.PPP,
     rel.WRTAFIC.compensation.per.employee.NUTS2.real.PPP,
     
     FBS.employment.NUTS2,
     FBS.compensation.of.employee.NUTS2.real.PPP,
     FBS.compensation.per.employee.NUTS2.real.PPP,
     rel.FBS.compensation.per.employee.NUTS2.real.PPP,
     
     NMS.employment.NUTS2,
     NMS.compensation.of.employee.NUTS2.real.PPP,
     NMS.compensation.per.employee.NUTS2.real.PPP,
     rel.NMS.compensation.per.employee.NUTS2.real.PPP,
     
     GVA.NUTS2.real.PPP,
     GVA.per.worker.NUTS2.real.PPP,
     rel.GVA.per.worker.NUTS2.real.PPP,
     GVA.per.worker.GR.NUTS2.real.PPP,
     GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     agri.GVA.NUTS2.real.PPP,
     agri.GVA.per.worker.NUTS2.real.PPP,
     rel.agri.GVA.per.worker.NUTS2.real.PPP,
     agri.GVA.per.worker.GR.NUTS2.real.PPP,
     agri.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     industry.GVA.NUTS2.real.PPP,
     industry.GVA.per.worker.NUTS2.real.PPP,
     rel.industry.GVA.per.worker.NUTS2.real.PPP,
     industry.GVA.per.worker.GR.NUTS2.real.PPP,
     industry.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     constr.GVA.NUTS2.real.PPP,
     constr.GVA.per.worker.NUTS2.real.PPP,
     rel.constr.GVA.per.worker.NUTS2.real.PPP,
     constr.GVA.per.worker.GR.NUTS2.real.PPP,
     constr.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     WRTAFIC.GVA.NUTS2.real.PPP,
     WRTAFIC.GVA.per.worker.NUTS2.real.PPP,
     rel.WRTAFIC.GVA.per.worker.NUTS2.real.PPP,
     WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP,
     WRTAFIC.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     FBS.GVA.NUTS2.real.PPP,
     FBS.GVA.per.worker.NUTS2.real.PPP,
     rel.FBS.GVA.per.worker.NUTS2.real.PPP,
     FBS.GVA.per.worker.GR.NUTS2.real.PPP,
     FBS.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     NMS.GVA.NUTS2.real.PPP,
     NMS.GVA.per.worker.NUTS2.real.PPP,
     rel.NMS.GVA.per.worker.NUTS2.real.PPP,
     NMS.GVA.per.worker.GR.NUTS2.real.PPP,
     NMS.GVA.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     GDP.NUTS2.real.PPP,
     GDP.per.worker.NUTS2.real.PPP,
     rel.GDP.per.worker.NUTS2.real.PPP,
     GDP.per.worker.GR.NUTS2.real.PPP,
     GDP.per.worker.GR.NUTS2.real.PPP.AvSample,
     
     share.tot.compensation.on.tot.GVA,
     share.agri.compensation.on.tot.GVA,
     share.industry.compensation.on.tot.GVA,
     share.constr.compensation.on.tot.GVA,
     share.WRTAFIC.compensation.on.tot.GVA,
     share.FBS.compensation.on.tot.GVA,
     share.NMS.compensation.on.tot.GVA,
     
     file = "dataset_GDP_GVA_compensation_PPP_real_for_analyisis_NUTS2.RData") 

#*******************************************************************************************
#*******************************************************************************************

##########################################
# Building spatial matrix from shapefile #
##########################################

source("geoMatrixCutOff_InverseExponential.R")
#source("geoMatrixAllLinked.R")
source("geoMatrix_knearneigh.R")

#Load the shape file 2016 for NUTS 2
x <- readOGR("NUTS_RG_01M_2016_3035_LEVL_2.shp")

#Merge the NUTS 2 of Switzerland
pippa1 <- x[x$NUTS_ID=="CH01",]
pippa2 <- x[x$NUTS_ID=="CH02",]
pippa3 <- x[x$NUTS_ID=="CH03",]
pippa4 <- x[x$NUTS_ID=="CH04",]
pippa5 <- x[x$NUTS_ID=="CH05",]
pippa6 <- x[x$NUTS_ID=="CH06",]
pippa7 <- x[x$NUTS_ID=="CH07",]
CH00 <- aggregate(rbind(pippa1,pippa2,pippa3,pippa4,pippa5,pippa6,pippa7))
CH00$NUTS_ID <-"CH00"
CH00$LEVL_CODE <- 2
CH00$CNTR_CODE <- "CH"
CH00$NUTS_NAME <- "Switzerland"
CH00$FID <- "CH00"
CH00 <- spChFIDs(CH00,"CH00")
x <- spRbind(CH00,x)

#Vector of positions of our regions in shp file
NUTS_RG_01M_2016_3035_LEVL_2.reorder <- numeric(length(code.NUTS2.our.sample))*NA
positions <- 1:length(x$NUTS_ID)
for (i in 1:length(code.NUTS2.our.sample)){
  NUTS_RG_01M_2016_3035_LEVL_2.reorder[i] <- positions[x$NUTS_ID==code.NUTS2.our.sample[i]]
}
EU.x  <- x[NUTS_RG_01M_2016_3035_LEVL_2.reorder,]

#************************************
#First-order contiguity matrix (0-1)
#************************************
countiguosMatrix <- poly2nb(EU.x)
spatialMatrixFirstOrderContiguity.listw <- nb2listw(countiguosMatrix, glist=NULL, style="B", zero.policy=TRUE)
spatialMatrixFirstOrderContiguity <- nb2mat(countiguosMatrix, glist=NULL, style="B", zero.policy=TRUE)
colnames(spatialMatrixFirstOrderContiguity) <- EU.x$NUTS_ID
rownames(spatialMatrixFirstOrderContiguity) <- EU.x$NUTS_ID
#spatialWeigthMatrixFirstOrderContiguity <- nb2mat(countiguosMatrix, glist=NULL, style="W", zero.policy=TRUE)
#colnames(spatialWeigthMatrixFirstOrderContiguity) <- EU.x$NUTS_ID
#rownames(spatialWeigthMatrixFirstOrderContiguity) <- EU.x$NUTS_ID

#**************************************
#Second-order contiguity matrix (0-1)
#**************************************
iii <- nblag(countiguosMatrix,2)
iii <- nblag_cumul(iii)
spatialMatrixSecondOrderContiguity.listw <- nb2listw(iii, glist=NULL, style="B", zero.policy=TRUE)
spatialMatrixSecondOrderContiguity <- nb2mat(iii, glist=NULL, style="B", zero.policy=TRUE)
colnames(spatialMatrixSecondOrderContiguity) <- EU.x$NUTS_ID
rownames(spatialMatrixSecondOrderContiguity) <- EU.x$NUTS_ID
#spatialWeigthMatrixSecondOrderContiguity <- nb2mat(iii, glist=NULL, style="W", zero.policy=TRUE)
#colnames(spatialWeigthMatrixSecondOrderContiguity) <- EU.x$NUTS_ID
#rownames(spatialWeigthMatrixSecondOrderContiguity) <- EU.x$NUTS_ID

#********************************
# Countries (0-1) spatial matrix  
#********************************
#List of countries
list.country <- substr(rownames(GDP.per.worker.NUTS2.real.PPP),start = 1,stop=2)
#Country spatial matrix
spatialMatrixCountry <- matrix(NA,nrow=length(list.country),ncol=length(list.country))

for (i in 1:length(list.country)){
  for (j in 1: length(list.country)){
    if(list.country[i]==list.country[j]){
      spatialMatrixCountry[i,j] <- 1
       }else{
         spatialMatrixCountry[i,j] <- 0}
  }  
}
diag(spatialMatrixCountry) <- 0
colnames(spatialMatrixCountry) <- EU.x$NUTS_ID
rownames(spatialMatrixCountry) <- EU.x$NUTS_ID


#*****************************************************************
# Different spatial weights W based on the geographical distance #
#*****************************************************************

centroid.x1.2 <- spTransform(EU.x, CRS("+proj=longlat +datum=WGS84"))
centroid.x1 <- coordinates(centroid.x1.2)

# Spatial matrix - Given two sets of longitudinal / latitude locations computes
# the Great circle (geographic) distance matrix among all pairings.

distanceMatrix <- rdist.earth(centroid.x1, miles=FALSE)
quantileDistance <- quantile(c(distanceMatrix), probs=c(0.25,0.5,0.75,1))

rownames(distanceMatrix) <- EU.x$NUTS_ID
colnames(distanceMatrix) <- EU.x$NUTS_ID
pippo <- distanceMatrix
diag(pippo) <- 1000000
apply(pippo,1,max)
sort(apply(pippo,1,min),decreasing=T)


#*****************************************************************
# Spatial matrices with cut-off and inverse distance squared 
#*****************************************************************
#First Quantile Q1, inverse distance squared
spatialMatrixNorm_Q1_dist2_mat <- geoMatrixCutOff_InverseExponential(centroids=centroid.x1, cutOff=quantileDistance[1], functionDist="inverse", alpha=2)$spatialMatrixNorm_mat
colnames(spatialMatrixNorm_Q1_dist2_mat) <- EU.x$NUTS_ID
rownames(spatialMatrixNorm_Q1_dist2_mat) <- EU.x$NUTS_ID

#Second Quantile Q2, inverse distance squared
spatialMatrixNorm_Q2_dist2_mat <- geoMatrixCutOff_InverseExponential(centroids=centroid.x1, cutOff=quantileDistance[2], functionDist="inverse", alpha=2)$spatialMatrixNorm_mat
colnames(spatialMatrixNorm_Q2_dist2_mat) <- EU.x$NUTS_ID
rownames(spatialMatrixNorm_Q2_dist2_mat) <- EU.x$NUTS_ID

#Third Quantile Q3, inverse distance squared
spatialMatrixNorm_Q3_dist2_mat <- geoMatrixCutOff_InverseExponential(centroids=centroid.x1, cutOff=quantileDistance[3], functionDist="inverse", alpha=2)$spatialMatrixNorm_mat
colnames(spatialMatrixNorm_Q3_dist2_mat) <- EU.x$NUTS_ID
rownames(spatialMatrixNorm_Q3_dist2_mat) <- EU.x$NUTS_ID

#Fourth quantile Q4 (no threshold), inverse distance squared
spatialMatrixNorm_Q4_dist2_mat <- geoMatrixCutOff_InverseExponential(centroids=centroid.x1, cutOff=quantileDistance[4], functionDist="inverse", alpha=2)$spatialMatrixNorm_mat
colnames(spatialMatrixNorm_Q4_dist2_mat) <- EU.x$NUTS_ID
rownames(spatialMatrixNorm_Q4_dist2_mat) <- EU.x$NUTS_ID

#**************************************************************************
# Spatial matrices with elements proportional to the K-nearest neighbours #
#**************************************************************************

#K=5
spatialMatrix_5NearestNeighbour <- geoMatrix_knearneigh(centroids=centroid.x1, kPar=5)$spatialMatrixNorm_mat
colnames(spatialMatrix_5NearestNeighbour) <- EU.x$NUTS_ID
rownames(spatialMatrix_5NearestNeighbour) <- EU.x$NUTS_ID

#K=10
spatialMatrix_10NearestNeighbour <- geoMatrix_knearneigh(centroids=centroid.x1, kPar=10)$spatialMatrixNorm_mat
colnames(spatialMatrix_10NearestNeighbour) <- EU.x$NUTS_ID
rownames(spatialMatrix_10NearestNeighbour) <- EU.x$NUTS_ID

#K=15
spatialMatrix_15NearestNeighbour <- geoMatrix_knearneigh(centroids=centroid.x1, kPar=15)$spatialMatrixNorm_mat
colnames(spatialMatrix_15NearestNeighbour) <- EU.x$NUTS_ID
rownames(spatialMatrix_15NearestNeighbour) <- EU.x$NUTS_ID


names_W <- c("spatialMatrixFirstOrderContiguity", "spatialMatrixSecondOrderContiguity", "spatialMatrixCountry", "spatialMatrixNorm_Q1_dist2_mat","spatialMatrixNorm_Q2_dist2_mat", "spatialMatrixNorm_Q3_dist2_mat", "spatialMatrixNorm_Q4_dist2_mat", "spatialMatrix_5NearestNeighbour","spatialMatrix_10NearestNeighbour", "spatialMatrix_15NearestNeighbour")

list.spatial.matrices <- list(spatialMatrixFirstOrderContiguity, spatialMatrixSecondOrderContiguity, spatialMatrixCountry,spatialMatrixNorm_Q1_dist2_mat,spatialMatrixNorm_Q2_dist2_mat,spatialMatrixNorm_Q3_dist2_mat,spatialMatrixNorm_Q4_dist2_mat,spatialMatrix_5NearestNeighbour,spatialMatrix_10NearestNeighbour,spatialMatrix_15NearestNeighbour)

names(list.spatial.matrices) <- names_W

#Save all the matrices
save(list.spatial.matrices, file="list_spatial_matrices_convergence_compensation.RData")



