####################################################
#
# Davide Fiaschi, Lisa Gianmoena, and Angela Parenti
#
# The Drivers of Inequality Across European Regions
#
# Last update 06/11/2019
# 
####################################################

#Remove any object
rm(list=ls(all=TRUE))

#Library
library(mgcv)
library(sm)
library(plm)
library(foreach)
library(doMC)
registerDoMC(12)

# Library for maps
library(dplyr)
library(ggplot2)
library(spdep)
library(sp)
library(maptools)
library(sf)
library(spectralGP)
library(gstat)
library(RColorBrewer)
library(plyr)
library(rgdal)
library(rgeos)
library(raster)

#Load Cambridge Econometrics dataset
load("cambridgeEconometrics_2016_18_10.RData")

#Load dataset with sectoral compensation
load("dataset_GDP_GVA_compensation_PPP_real_for_analyisis_NUTS2.RData")

#Load price levels
load("price.country.level.RData")

#Source
source("univariateDensityAdaptive_Parallel.r")
source("weighted.sd.r")
source("bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel.r")
source("numericalIntegration.r")
source("generalized.entropy.measure.R")

#Years of analysis
years <- as.numeric(colnames(constr.compensation.per.employee.NUTS2.real.PPP))

#NUTS 2 in our sample
code.NUTS2.our.sample <- rownames(constr.compensation.per.employee.NUTS2.real.PPP)

if(0==1){
###########################################################
# The estimate of stochatic kernel for sector compensation
###########################################################

##ATTENTION: the computational burder exponentially increases with 
#ngridPar and the number of bootstrasps
#ngridPar = 150 and B=100 is a good compromize (with 12 CPU about 2 hour)

#Number of lag
num.lag <- 5
  
#Set parameters for estimation
#Range of observations for stochastic kernel
rangeOBS <- c(-0.25,2.5)
#Number of evaluation points for stochastic kernel  
ngridPar <- 25
# Alpha parameter of the bivariate and univariate adaptive kernel
alpha <- 0.5
alpha.uni.density <- 0.5
#Number of bootstraps for the median and the ergodic of stochastic kernel  
B <- 2
#Parameter for the plot
nlevelsPar <- 10

#Total compensation per employee
ini <- 1992
fin <- 2015
actObs <- c(as.matrix(rel.tot.compensation.per.employee.NUTS2.real.PPP[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c(ini:(fin-num.lag))]))
futObs <- c(as.matrix(rel.tot.compensation.per.employee.NUTS2.real.PPP[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c((ini+num.lag):fin)]))
#Check for NA
kkk <- !is.na(actObs) & !is.na(futObs)
actObs <- actObs[kkk]
futObs <- futObs[kkk]
t1 <- Sys.time()
stocKernel.tot.compensation.per.employee <- bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel(x=cbind(futObs,actObs),rangeObs.x=rangeOBS,rangeObs.y=rangeOBS, ngrid=ngridPar,alpha=0.5,figure=TRUE,ergodicDistr=TRUE,obsNormalized=TRUE)
print(Sys.time()- t1)

#Compensation per employee in industry
actObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$Industry[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c(ini:(fin-num.lag))]))
futObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$Industry[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c((ini+num.lag):fin)]))
#Check for NA
kkk <- !is.na(actObs) & !is.na(futObs)
actObs <- actObs[kkk]
futObs <- futObs[kkk]
t1 <- Sys.time()
stocKernel.compensation.per.employee.industry <- bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel(x=cbind(futObs,actObs),rangeObs.x=rangeOBS,rangeObs.y=rangeOBS, ngrid=ngridPar,alpha=0.5,figure=TRUE,ergodicDistr=TRUE,obsNormalized=TRUE)
print(Sys.time()- t1)

#Compensation per employee in construction
actObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$Construction[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c(ini:(fin-num.lag))]))
futObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$Construction[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c((ini+num.lag):fin)]))
#Check for NA
kkk <- !is.na(actObs) & !is.na(futObs)
actObs <- actObs[kkk]
futObs <- futObs[kkk]
t1 <- Sys.time()
stocKernel.compensation.per.employee.construction <- bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel(x=cbind(futObs,actObs),rangeObs.x=rangeOBS,rangeObs.y=rangeOBS, ngrid=ngridPar,alpha=0.5,figure=TRUE,ergodicDistr=TRUE,obsNormalized=TRUE)
print(Sys.time()- t1)

#Compensation per employee in non market service
actObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$`Non-Market Services`[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c(ini:(fin-num.lag))]))
futObs <- c(as.matrix(list.rel.sector.compensation.per.employee.NUTS2.real.PPP$`Non-Market Services`[,colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)%in%c((ini+num.lag):fin)]))
#Check for NA
kkk <- !is.na(actObs) & !is.na(futObs)
actObs <- actObs[kkk]
futObs <- futObs[kkk]
t1 <- Sys.time()
stocKernel.compensation.per.employee.NMS <- bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel(x=cbind(futObs,actObs),rangeObs.x=rangeOBS,rangeObs.y=rangeOBS, ngrid=ngridPar,alpha=0.5,figure=TRUE,ergodicDistr=TRUE,obsNormalized=TRUE)
print(Sys.time()- t1)
}

#****************************************
# Build the dataset for Panel estimation
#****************************************

# Relative compensation per employee in relative terms (PPP, base year 2005)
rel.compensation.Total <-  as.matrix(rel.tot.compensation.per.employee.NUTS2.real.PPP)
rel.compensation.Agriculture <- as.matrix(rel.agri.compensation.per.employee.NUTS2.real.PPP)
rel.compensation.Industry <- as.matrix(rel.industry.GVA.per.worker.NUTS2.real.PPP)
rel.compensation.Construction <- as.matrix(rel.constr.compensation.per.employee.NUTS2.real.PPP)
rel.compensation.WRTAFIC <- as.matrix(rel.WRTAFIC.compensation.per.employee.NUTS2.real.PPP)
rel.compensation.FBS <- as.matrix(rel.FBS.compensation.per.employee.NUTS2.real.PPP)
rel.compensation.NonMarketServices <- as.matrix(rel.NMS.compensation.per.employee.NUTS2.real.PPP)

####################################
#Set up the panel for estimation
num.regions <- nrow(rel.tot.compensation.per.employee.NUTS2.real.PPP)
num.periods <- ncol(rel.tot.compensation.per.employee.NUTS2.real.PPP)

#Lag in the dynamic panel
num.lag <- 10

# regions' labels
regLabPan <- rep(rownames(rel.tot.compensation.per.employee.NUTS2.real.PPP),times=(num.periods-num.lag))       # set it up for the panel
perPan <- rep(colnames(rel.tot.compensation.per.employee.NUTS2.real.PPP)[(1+num.lag):ncol(rel.tot.compensation.per.employee.NUTS2.real.PPP)],each=num.regions) # set up the variable indicating the period for the panel
#cbind(regLabPan,perPan)

#Stacking
rel.compensation.tot.stacked <- matrix(t(rel.tot.compensation.per.employee.NUTS2.real.PPP[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.agriculture.stacked <- matrix(t(rel.compensation.Agriculture[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.industry.stacked <- matrix(t(rel.compensation.Industry[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.construction.stacked <- matrix(t(rel.compensation.Construction[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.WRTAFIC.stacked <- matrix(t(rel.compensation.WRTAFIC[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.FBS.stacked <- matrix(t(rel.compensation.FBS[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
rel.compensation.nonMarketServices.stacked <- matrix(t(rel.compensation.NonMarketServices[,(num.lag+1):num.periods]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)

lag.rel.compensation.tot.stacked <- matrix(t(rel.tot.compensation.per.employee.NUTS2.real.PPP[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.agriculture.stacked <- matrix(t(rel.compensation.Agriculture[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.industry.stacked <- matrix(t(rel.compensation.Industry[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.construction.stacked <- matrix(t(rel.compensation.Construction[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.WRTAFIC.stacked <- matrix(t(rel.compensation.WRTAFIC[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.FBS.stacked <- matrix(t(rel.compensation.FBS[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)
lag.rel.compensation.nonMarketServices.stacked <- matrix(t(rel.compensation.NonMarketServices[,1:(num.periods-num.lag)]),ncol=1,nrow=num.regions*(num.periods-num.lag),byrow=TRUE)

myVariables <- cbind(rel.compensation.tot.stacked,
                     rel.compensation.agriculture.stacked,
                     rel.compensation.industry.stacked,
                     rel.compensation.construction.stacked,
                     rel.compensation.WRTAFIC.stacked,
                     rel.compensation.FBS.stacked,
                     rel.compensation.nonMarketServices.stacked,
                     lag.rel.compensation.tot.stacked,
                     lag.rel.compensation.agriculture.stacked,
                     lag.rel.compensation.industry.stacked,
                     lag.rel.compensation.construction.stacked,
                     lag.rel.compensation.WRTAFIC.stacked,
                     lag.rel.compensation.FBS.stacked,
                     lag.rel.compensation.nonMarketServices.stacked
                     )

varList <- c("compensation.tot","compensation.agriculture","compensation.industry",
             "compensation.construction","compensation.WRTAFIC","compensation.FBS",
             "compensation.nonMarketServices",
             "lag.compensation.tot","lag.compensation.agriculture","lag.compensation.industry",
             "lag.compensation.construction","lag.compensation.WRTAFIC","lag.compensation.FBS",
             "lag.compensation.nonMarketServices"
)

colnames(myVariables) <-  varList

myPanel <- data.frame(regLabPan, perPan, myVariables,stringsAsFactors=FALSE)
colnames(myPanel)<-  c("regLabPan", "perPan" ,varList)
myPanel_all <- pdata.frame(myPanel,index=c("regLabPan","perPan"))

#######################################################
#Estimate of a panel model with num lag and time effect

#Estimation for total compensation per employee
est.tot <- plm(log(compensation.tot) ~ log(lag.compensation.tot) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.tot <- fixef(est.tot)
summary(est.tot)
#summary(time.effect.est.tot)
#summary(lm(log(as.numeric(myPanel_all$compensation.tot)) ~ log(as.numeric(myPanel_all$lag.compensation.tot))  ))

#Estimation for compensation per employee in agriculture
est.agriculture <- plm(log(compensation.agriculture) ~ log(lag.compensation.agriculture) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.agriculture <- fixef(est.agriculture)
summary(est.agriculture)
#summary(time.effect.est.tot)

#Estimation for compensation per employee in industry
est.industry <- plm(log(compensation.industry) ~ log(lag.compensation.industry) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.industry <- fixef(est.industry)
summary(est.industry)
#summary(time.effect.est.industry)

#Estimation for compensation per employee in construction
est.construction <- plm(log(compensation.construction) ~ log(lag.compensation.construction) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.construction <- fixef(est.construction)
summary(est.construction)
#summary(time.effect.est.construction)

#Estimation for compensation per employee in WRTAFIC
est.WRTAFIC <- plm(log(compensation.WRTAFIC) ~ log(lag.compensation.WRTAFIC) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.WRTAFIC <- fixef(est.WRTAFIC)
summary(est.WRTAFIC)
#summary(time.effect.est.WRTAFIC)

#Estimation for compensation per employee in FBS
est.FBS <- plm(log(compensation.FBS) ~ log(lag.compensation.FBS) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.FSB <- fixef(est.FBS)
summary(est.FBS)
#summary(time.effect.est.FSB)

#Estimation for compensation per employ in non market services
est.nms <- plm(log(compensation.nonMarketServices) ~ log(lag.compensation.nonMarketServices) -1, data=myPanel_all,model="within",effect="twoways")
time.effect.est.nms <- fixef(est.nms)
summary(est.nms)
#summary(time.effect.est.nms)
