generalized.entropy.measure <- function(x,wei=rep(1,length(x)),c.par=0,groups=rep(1,length(x))){
  
  #Generalized entropy measure index for weighted and grouped observarions
  
  #Input
  # x: vector of observations
  # wei: sample's weight
  #c.par: parameter of the generalized entropy measure (Foster and Shneyerov, 1999, Economic Theory, p. 94). c=0 gives second Theil measure, c=1 first Theil measure, and c can be in [0,+infinity]
  # groups: a vector of the same length of x given the division in groups
  
  #Return: Theil aggregate index and the division between within and between inequality
  
  #Check for na values
  not.na <- !is.na(x)
  x <- x[not.na]
  wei <- wei[not.na]
  groups <- groups[not.na]
  if (sum(!not.na>0)){
    print("#----------------------------------------------------------------#",quote=FALSE)
    print("ATTENTION: NA observations have been discarded in the calculation!",quote=FALSE)
    print("#----------------------------------------------------------------#",quote=FALSE)
  }
  
  #Number of the observations in the sample not na
  n <- length(x)
  
  #Normalization of the sample's weights to unit
  wei <- wei/sum(wei)
    
  #Normalization of the sample's observations
  xmean <- weighted.mean(x,wei)
  xNorm <- x/xmean
  
  #Number of groups
  list.groups <- unique(groups)
  num.groups <- length(list.groups)
  
  #Calculation of generalized entropy measure (GEM) and its decomposition
  if (c.par==0){
    GEM.index <- -sum(wei*log(xNorm))
    
    #Decompostion of index
    vector.smoothed.distr <- vector(mode="numeric",length=length(x))
    for (i in 1:num.groups){
      yyy <- groups==list.groups[i]
      vector.smoothed.distr[yyy] <- weighted.mean(xNorm[yyy],wei[yyy])
      
    }
    
    GEM.index.between <- -sum(wei*log(vector.smoothed.distr))
    
    GEM.index.within <- GEM.index - GEM.index.between
    
  }
  if (c.par==1){
    GEM.index <- sum(wei*xNorm*log(xNorm))
    
    #Decompostion of index
    vector.smoothed.distr <- vector(mode="numeric",length=length(x))
    for (i in 1:num.groups){
      yyy <- groups==list.groups[i]
      vector.smoothed.distr[yyy] <- weighted.mean(xNorm[yyy],wei[yyy])
      
    }
    GEM.index.between <- sum(wei*vector.smoothed.distr*log(vector.smoothed.distr))
    
    GEM.index.within <- GEM.index - GEM.index.between
    
  }
  if ( (c.par!=0) & (c.par!=1) ){
     GEM.index <- - (1/(c.par*(1-c.par)))*sum(wei*(xNorm^c.par-1))
     
     #Decompostion of index
     vector.smoothed.distr <- vector(mode="numeric",length=length(x))
     for (i in 1:num.groups){
       yyy <- groups==list.groups[i]
       vector.smoothed.distr[yyy] <- weighted.mean(xNorm[yyy],wei[yyy])
       
     }
     GEM.index.between <- - (1/(c.par*(1-c.par)))*sum(wei*(vector.smoothed.distr^c.par-1))
     
     GEM.index.within <- GEM.index - GEM.index.between
     
    
  }
  
  
  list(GEM.index=GEM.index,GEM.index.between=GEM.index.between,GEM.index.within=GEM.index.within)
  
}