####################################################
#
# Davide Fiaschi, Lisa Gianmoena, and Angela Parenti
#
# The Drivers of Inequality Across European Regions
#
# Last update 05/11/2019
# 
####################################################


#Remove any object
rm(list=ls(all=TRUE))

#Remove any object
rm(list=ls(all=TRUE))

#Library
library(mgcv)
library(sm)
library(plm)
library(foreach)
library(doMC)
registerDoMC(12)

# Library for maps
library(dplyr)
library(ggplot2)
library(spdep)
library(sp)
library(maptools)
library(sf)
library(spectralGP)
library(gstat)
library(RColorBrewer)
library(plyr)
library(rgdal)
library(rgeos)
library(raster)

#Source
source("univariateDensityAdaptive_Parallel.r")
source("weighted.sd.r")
source("bivariateDensityKernelAdaptiveDifferentRanges_Matrix_Parallel.r")
source("numericalIntegration.r")

# load the dataset
load("dataset_GDP_GVA_compensation_PPP_real_for_analyisis_NUTS2.RData")

# what we do:
# 1. picture of compensation per employee
# 3. GVA and GDP
# 3. MAP

years <- 1990:2018

#==============================
# Plot the average growth rate of compensation per employee vs GDP and GVA per worker
#==============================
dev.new()
plot(1993:2015,tot.compensation.per.employee.GR.NUTS2.real.PPP.AvSample, xlab="Year", ylab="Annual average of regional growth rates", xaxp=c(1993, 2015, length(1993:2015)-1),main="Growth rate of compensation, GDP and GVA per worker",  col="black", ylim=c(-0.02,0.09),type="b",pch=19)
lines(1993:2015,GDP.per.worker.GR.NUTS2.real.PPP.AvSample,lwd=2,col="red",pch=4,type="b")
lines(1993:2015,GVA.per.worker.GR.NUTS2.real.PPP.AvSample,lwd=2,col="blue",pch=5,type="b")
abline(h=0)
grid()
legend("topright", col=c("black","red","blue"),pch = c(19,4,5),lwd=2,c("Compensation per employee", "GDP per worker","GVA per worker"))
dev.copy2eps(file="growthRateCompensationPerEmployee.eps")

##############################################
#Total compensation
est.density.1992 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,1]),1]),figure = FALSE)
est.density.1997 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,6]),6]),figure = FALSE)
est.density.2003 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,12]),12]),figure = FALSE)
est.density.2006 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,15]),15]),figure = FALSE)
est.density.2007 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,16]),16]),figure = FALSE)
est.density.2008 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,17]),17]),figure = FALSE)
est.density.2009 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,18]),18]),figure = FALSE)
est.density.2010 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,19]),19]),figure = FALSE)
est.density.2012 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,21]),21]),figure = FALSE)
est.density.2015 <- univariateDensityAdaptive_Parallel(log(tot.compensation.per.employee.NUTS2.real.PPP[!is.na(tot.compensation.per.employee.NUTS2.real.PPP[,24]),24]),figure = FALSE)

dev.new()
plot(est.density.1992$eval.points,est.density.1992$estimate,main ="Compensation per employee (log scale)",xlab = "Compensation per employee (log scale, real, base year 2005, PPP, EU28=1)",ylab = "Marginal density",xlim=c(6.4,11.8),type="l",ylim=c(0,1.63))
lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
legend("topleft",ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)
grid()
dev.copy2eps(file="distributionCompensationPerEmployee.eps")

#Relative compensation
est.density.1992 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,1]),1],figure = FALSE)
est.density.1997 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,6]),6],figure = FALSE)
est.density.2003 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,12]),12],figure = FALSE)
est.density.2006 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,15]),15],figure = FALSE)
est.density.2007 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,16]),16],figure = FALSE)
est.density.2008 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,17]),17],figure = FALSE)
est.density.2009 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,18]),18],figure = FALSE)
est.density.2010 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,19]),19],figure = FALSE)
est.density.2012 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,21]),21],figure = FALSE)
est.density.2015 <- univariateDensityAdaptive_Parallel(rel.tot.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.tot.compensation.per.employee.NUTS2.real.PPP[,24]),24],figure = FALSE)

dev.new()
plot(est.density.1992$eval.points,est.density.1992$estimate,xlim=c(0,2.5),type="l",ylim=c(0,1.5),main ="Compensation per employee (rel.)",xlab = "Relative compensation per employee (real, base year 2005, PPP, EU28=1)",ylab = "Marginal density")
lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
legend("topright",ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)
grid()
dev.copy2eps(file="distributionRelativeCompensationPerEmployee.eps")

#=========================
# Sectoral Compensation
#=========================

sector.name <- c("Agriculture", "Industry", "Construction", "WRTAFIC", "FBS", "NMS")
sector.compensation.variable <- list(agri.compensation.per.employee.NUTS2.real.PPP,
                                     industry.compensation.per.employee.NUTS2.real.PPP,
                                     constr.compensation.per.employee.NUTS2.real.PPP,
                                     WRTAFIC.compensation.per.employee.NUTS2.real.PPP,
                                     FBS.compensation.per.employee.NUTS2.real.PPP,
                                     NMS.compensation.per.employee.NUTS2.real.PPP)

names(sector.compensation.variable) <- c("agri.compensation.per.employee.NUTS2.real.PPP",
                                         "industry.compensation.per.employee.NUTS2.real.PPP",
                                         "constr.compensation.per.employee.NUTS2.real.PPP",
                                         "WRTAFIC.compensation.per.employee.NUTS2.real.PPP",
                                         "FBS.compensation.per.employee.NUTS2.real.PPP",
                                         "NMS.compensation.per.employee.NUTS2.real.PPP")


dev.new()
par(mfrow=c(2,3))

for(s in 1:length(sector.name)){
  print(sector.name[s])
  
  # load the dataset collected in a list 
  sector.compensation.per.employee.NUTS2.real.PPP <-  sector.compensation.variable[[s]]
  
  est.density.1992 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,1]),1]), figure=F)
  est.density.1997 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,6]),6]), figure=F)
  est.density.2003 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,12]),12]), figure=F)
  est.density.2006 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,15]),15]), figure=F)
  est.density.2007 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,16]),16]), figure=F)
  est.density.2008 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,17]),17]), figure=F)
  est.density.2009 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,18]),18]), figure=F)
  est.density.2010 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,19]),19]), figure=F)
  est.density.2012 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,21]),21]), figure=F)
  est.density.2015 <- univariateDensityAdaptive_Parallel(log(sector.compensation.per.employee.NUTS2.real.PPP[!is.na(sector.compensation.per.employee.NUTS2.real.PPP[,24]),24]), figure=F)
  
  plot(est.density.1992$eval.points,est.density.1992$estimate, xlim=c(4,11.5), ylim=c(0,2.3), type="l",main =sector.name[s],xlab = "Compensation per employee",ylab = "Marginal density")
  
  lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
  lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
  lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
  lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
  lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
  lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
  lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
  lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
  lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
  legend("topleft", ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)
  
}

dev.copy2eps(file="sectoralDistributionDynamicsAbsCompensationPerEmployee.eps")

#Relative
sector.name <- c("Agriculture", "Industry", "Construction", "WRTAFIC", "FBS", "NMS")
sector.compensation.variable <- list(rel.agri.compensation.per.employee.NUTS2.real.PPP,
                                     rel.industry.compensation.per.employee.NUTS2.real.PPP,
                                     rel.constr.compensation.per.employee.NUTS2.real.PPP,
                                     rel.WRTAFIC.compensation.per.employee.NUTS2.real.PPP,
                                     rel.FBS.compensation.per.employee.NUTS2.real.PPP,
                                     rel.NMS.compensation.per.employee.NUTS2.real.PPP)

names(sector.compensation.variable) <- c("rel.agri.compensation.per.employee.NUTS2.real.PPP",
                                         "rel.industry.compensation.per.employee.NUTS2.real.PPP",
                                         "rel.constr.compensation.per.employee.NUTS2.real.PPP",
                                         "rel.WRTAFIC.compensation.per.employee.NUTS2.real.PPP",
                                         "rel.FBS.compensation.per.employee.NUTS2.real.PPP",
                                         "rel.NMS.compensation.per.employee.NUTS2.real.PPP")


dev.new()
par(mfrow=c(2,3))

for(s in 1:length(sector.name)){
  print(sector.name[s])
  
  # load the dataset collected in a list 
  rel.sector.compensation.per.employee.NUTS2.real.PPP <-  sector.compensation.variable[[s]]
  
  est.density.1992 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,1]),1], figure=F)
  est.density.1997 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,6]),6], figure=F)
  est.density.2003 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,12]),12], figure=F)
  est.density.2006 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,15]),15], figure=F)
  est.density.2007 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,16]),16], figure=F)
  est.density.2008 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,17]),17], figure=F)
  est.density.2009 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,18]),18], figure=F)
  est.density.2010 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,19]),19], figure=F)
  est.density.2012 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,21]),21], figure=F)
  est.density.2015 <- univariateDensityAdaptive_Parallel(rel.sector.compensation.per.employee.NUTS2.real.PPP[!is.na(rel.sector.compensation.per.employee.NUTS2.real.PPP[,24]),24], figure=F)
  
  plot(est.density.1992$eval.points,est.density.1992$estimate, xlim=c(0,3), ylim=c(0,1.5), type="l",
       main =sector.name[s],xlab = "Relative compensation per employee",ylab = "Marginal density")
  
  lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
  lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
  lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
  lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
  lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
  lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
  lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
  lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
  lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
  legend("topright", ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)
  
}

dev.copy2eps(file="sectoralDistributionDynamicsCompensationPerEmployee.eps")


#===========
# Total GVA 
#===========

est.density.1992 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,1]),1], figure=F)
est.density.1997 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,6]),6], figure=F)
est.density.2003 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,12]),12], figure=F)
est.density.2006 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,15]),15], figure=F)
est.density.2007 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,16]),16], figure=F)
est.density.2008 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,17]),17], figure=F)
est.density.2009 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,18]),18], figure=F)
est.density.2010 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,19]),19], figure=F)
est.density.2012 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,21]),21], figure=F)
est.density.2015 <- univariateDensityAdaptive_Parallel(rel.GVA.per.worker.NUTS2.real.PPP[!is.na(rel.GVA.per.worker.NUTS2.real.PPP[,24]),24], figure=F)

dev.new()
plot(est.density.1992$eval.points,est.density.1992$estimate,xlim=c(0,2.5),type="l",ylim=c(0,2),main ="TOTAL GVA.pw",xlab = "Relative GVA per worker (real, base year 2005)",ylab = "Marginal density")
lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
legend("topright", ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)


#=========================
# Sectoral GVA  PER WORKER
#=========================

sector.GVA.variable <- list(rel.agri.GVA.per.worker.NUTS2.real.PPP,
                            rel.industry.GVA.per.worker.NUTS2.real.PPP,
                            rel.constr.GVA.per.worker.NUTS2.real.PPP,
                            rel.WRTAFIC.GVA.per.worker.NUTS2.real.PPP,
                            rel.FBS.GVA.per.worker.NUTS2.real.PPP,
                            rel.NMS.GVA.per.worker.NUTS2.real.PPP)

names(sector.GVA.variable) <- c("rel.agri.GVA.per.worker.NUTS2.real.PPP",
                                         "rel.industry.GVA.per.worker.NUTS2.real.PPP",
                                         "rel.constr.GVA.per.worker.NUTS2.real.PPP",
                                         "rel.WRTAFIC.GVA.per.worker.NUTS2.real.PPP",
                                         "rel.FBS.GVA.per.worker.NUTS2.real.PPP",
                                         "rel.NMS.GVA.per.worker.NUTS2.real.PPP")

dev.new()
par(mfrow=c(2,3))

for(s in 1:length(sector.name)){
  print(sector.name[s])
  
  # load the dataset collected in a list 
rel.sector.GVA.per.worker.NUTS2 <- sector.GVA.variable[[s]]

est.density.1992 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,1]),1], figure=F)
est.density.1997 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,6]),6], figure=F)
est.density.2003 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,12]),12], figure=F)
est.density.2006 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,15]),15], figure=F)
est.density.2007 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,16]),16], figure=F)
est.density.2008 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,17]),17], figure=F)
est.density.2009 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,18]),18], figure=F)
est.density.2010 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,19]),19], figure=F)
est.density.2012 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,21]),21], figure=F)
est.density.2015 <- univariateDensityAdaptive_Parallel(rel.sector.GVA.per.worker.NUTS2[!is.na(rel.sector.GVA.per.worker.NUTS2[,24]),24], figure=F)

plot(est.density.1992$eval.points,est.density.1992$estimate,xlim=c(0,2.5),type="l",ylim=c(0,1.6),main =sector.name[s],xlab = "Relative GVA per worker (real, base year 2005)",ylab = "Marginal density")
lines(est.density.1997$eval.points,est.density.1997$estimate,col="blue")
lines(est.density.2003$eval.points,est.density.2003$estimate,col="green")
lines(est.density.2006$eval.points,est.density.2006$estimate,col="pink")
lines(est.density.2007$eval.points,est.density.2007$estimate,col="grey")
lines(est.density.2008$eval.points,est.density.2008$estimate,col="cyan")
lines(est.density.2009$eval.points,est.density.2009$estimate,col="orange")
lines(est.density.2010$eval.points,est.density.2010$estimate,col="brown")
lines(est.density.2012$eval.points,est.density.2012$estimate,col="purple")
lines(est.density.2015$eval.points,est.density.2015$estimate,col="red")
legend("topright", ncol=1,legend=years[c(1,6,12,15,16,17,18,19,21,24)],col=c("black","blue","green","pink","gray","cyan","orange","brown","purple","red"),lwd=1)
}


#===========
# 3. Maps
#===========

#****************
# NUTS 0  borders
#****************

# NUTS0.sample <- unique(substr(code.NUTS2.our.sample, start = 1, stop=2))
#Load the shape file 2016 for NUTS 0
x.nuts0 <- readOGR("NUTS_RG_01M_2016_3035_LEVL_0.shp")

NUTS0.sample <- x.nuts0$NUTS_ID

#Vector of positions of our regions in shp file
NUTS_RG_01M_2016_3035_LEVL_0.reorder <- numeric(length(NUTS0.sample))*NA
positions <- 1:length(x.nuts0$NUTS_ID)
for (i in 1:length(NUTS0.sample)){
  NUTS_RG_01M_2016_3035_LEVL_0.reorder[i] <- positions[x.nuts0$NUTS_ID==NUTS0.sample[i]]
}
# cbind(NUTS0.sample,as.character(x.nuts0$NUTS_ID[NUTS_RG_01M_2016_3035_LEVL_0.reorder]))
EU.nuts0.x  <- x.nuts0[NUTS_RG_01M_2016_3035_LEVL_0.reorder,]

# Extract and add the information related to the coordiante 
#1. coerce to points, then to data frame
# names are Lines.NR Lines.ID Line.NR coords.x1 coords.x2
## start here for polys
lin <- as(EU.nuts0.x, "SpatialLinesDataFrame")  
## start here for lines
pts <- as.data.frame(as(lin, "SpatialPointsDataFrame"))

#2. convert to matrix 
# names are object part cump hole x y
mpts <- raster::geom(EU.nuts0.x)

#3. convert to data frame
# names are        long      lat order  hole piece  id group
dpts <- ggplot2::fortify(EU.nuts0.x)

EU.nuts0.x.df.coordinate <- cbind(dpts, pts)

#****************
# NUTS 2  borders
#****************
NUTS2.sample <- code.NUTS2.our.sample

#Load the shape file 2016 for NUTS 2
x <- readOGR("NUTS_RG_01M_2016_3035_LEVL_2.shp")

#Merge the NUTS 2 of Switzerland
pippa1 <- x[x$NUTS_ID=="CH01",]
pippa2 <- x[x$NUTS_ID=="CH02",]
pippa3 <- x[x$NUTS_ID=="CH03",]
pippa4 <- x[x$NUTS_ID=="CH04",]
pippa5 <- x[x$NUTS_ID=="CH05",]
pippa6 <- x[x$NUTS_ID=="CH06",]
pippa7 <- x[x$NUTS_ID=="CH07",]
# plot(pippa1,axes=T,xlim=c(3500000,4500000),ylim=c(2500000,2700000))
# plot(pippa2,add=T)
# plot(pippa3,add=T)
# plot(pippa4,add=T)
# plot(pippa5,add=T)
# plot(pippa6,add=T)
# plot(pippa7,add=T)
CH00 <- aggregate(rbind(pippa1,pippa2,pippa3,pippa4,pippa5,pippa6,pippa7))
CH00$NUTS_ID <-"CH00"
CH00$LEVL_CODE <- 2
CH00$CNTR_CODE <- "CH"
CH00$NUTS_NAME <- "Switzerland"
CH00$FID <- "CH00"

#plot(CH00)
#x <- x[!x$NUTS_ID %in% c("CH01","CH02","CH03","CH04","CH05","CH06","CH07"),] 
#x <- spChFIDs(x,as.character(x$NUTS_ID))
CH00 <- spChFIDs(CH00,"CH00")
x <- spRbind(CH00,x)
#plot(x,xlim=c(2500000,6500000),ylim=c(2500000,4700000))


#Vector of positions of our regions in shp file
NUTS_RG_01M_2016_3035_LEVL_2.reorder <- numeric(length(NUTS2.sample))*NA
positions <- 1:length(x$NUTS_ID)
for (i in 1:length(NUTS2.sample)){
  NUTS_RG_01M_2016_3035_LEVL_2.reorder[i] <- positions[x$NUTS_ID==NUTS2.sample[i]]
}

#cbind(NUTS2.sample,as.character(x$NUTS_ID[NUTS_RG_60M_2016_3035_LEVL_2.reorder]))
EU.x  <- x[NUTS_RG_01M_2016_3035_LEVL_2.reorder,]

# Extract and add the information related to the coordinate 
#1. coerce to points, then to data frame
# names are Lines.NR Lines.ID Line.NR coords.x1 coords.x2
## start here for polys
lin <- as(EU.x, "SpatialLinesDataFrame")  
## start here for lines
pts <- as.data.frame(as(lin, "SpatialPointsDataFrame"))

#2. convert to matrix 
# names are object part cump hole x y
mpts <- raster::geom(EU.x)

#3. convert to data frame
# names are        long      lat order  hole piece  id group
dpts <- ggplot2::fortify(EU.x)

EU.x.df.coordinate <- cbind(dpts, pts)

#******************************
# select the variables to plot 
#*****************************
 x.var <- rel.tot.compensation.per.employee.NUTS2.real.PPP
# x.var <- tot.employment.NUTS2
# x.var <- rel.GDP.per.worker.NUTS2.real.PPP

 #******
 # 1992
 #******
 x.var.1992 <- x.var$`1992`  
 names(x.var.1992) <- NUTS2.sample
 x.var.1992 <- x.var.1992[!is.na(x.var.1992)]
 NUTS2.sample.1992 <- names(x.var.1992)
 
# Regional data 1992
 data.1992 <- data.frame(cbind(NUTS2.sample.1992,x.var.1992))
 colnames(data.1992)[1] <- "NUTS_ID"
 
 #*******
 # 2015
 #******
  x.var.2015 <- x.var$`2015`  
 names(x.var.2015) <- NUTS2.sample
 x.var.2015 <- x.var.2015[!is.na(x.var.2015)]
 NUTS2.sample.2015 <- names(x.var.2015)
 
 # Regional data 2015
 data.2015 <- data.frame(cbind(NUTS2.sample.2015,x.var.2015))
 colnames(data.2015)[1] <- "NUTS_ID"
 
 # Merge of datasets and map
 joint.EU.df.1992 <- inner_join(EU.x.df.coordinate, data.1992, by = "NUTS_ID")
 joint.EU.df.2015 <- inner_join(EU.x.df.coordinate, data.2015, by = "NUTS_ID")
 
 # Colours of maps based on quantile distribution
 colours.x <- rev(gray.colors(5, start = 0.05, end = 0.8, gamma = 2.2, alpha = NULL))
 colour.vector.1992 <- vector(mode="character",length=length(joint.EU.df.1992$x.var.1992))
 colour.vector.2015 <- vector(mode="character",length=length(joint.EU.df.2015$x.var.2015))
 
 # here use paste fanctuon to mamage the mess driven by factor elements
 quantile.1992 <- quantile(as.numeric(paste(joint.EU.df.1992$x.var.1992)),probs = seq(0, 1, 0.20))
 quantile.2015 <- quantile(as.numeric(paste(joint.EU.df.2015$x.var.2015)),probs = seq(0, 1, 0.20))
 
 for (i in 1:5){
   colour.vector.1992[(as.numeric(paste(joint.EU.df.1992$x.var.1992))>=quantile.1992[1+(i-1)] & as.numeric(paste(joint.EU.df.1992$x.var.1992))<=quantile.1992[2+(i-1)])] <- colours.x[i]
   colour.vector.2015[(as.numeric(paste(joint.EU.df.2015$x.var.2015))>=quantile.2015[1+(i-1)] & as.numeric(paste(joint.EU.df.2015$x.var.2015))<=quantile.2015[2+(i-1)])] <- colours.x[i]
 }
 
 ditch_the_axes <- theme(
   axis.text = element_blank(),
   axis.line = element_blank(),
   axis.ticks = element_blank(),
   panel.border = element_blank(),
   panel.grid = element_blank(),
   axis.title = element_blank()
 )
 
 quantile.1992 <- round(quantile(as.numeric(paste(joint.EU.df.1992$x.var.1992)),probs = seq(0, 1, 0.20)),digits = 2)
 labels.range.1992  <- rev(c(
   paste(as.character(quantile.1992[1]),"-",as.character(quantile.1992[2])),
   paste(as.character(quantile.1992[2]),"-",as.character(quantile.1992[3])),
   paste(as.character(quantile.1992[3]),"-",as.character(quantile.1992[4])),
   paste(as.character(quantile.1992[4]),"-",as.character(quantile.1992[5]))
   ,paste(as.character(quantile.1992[5]),"-",as.character(quantile.1992[6]))
 ))
 
 
 quantile.2015 <- round(quantile(as.numeric(paste(joint.EU.df.2015$x.var.2015)),probs = seq(0, 1, 0.20)),digits = 2)
 labels.range.2015  <- rev(c(
   paste(as.character(quantile.2015[1]),"-",as.character(quantile.2015[2])),
   paste(as.character(quantile.2015[2]),"-",as.character(quantile.2015[3])),
   paste(as.character(quantile.2015[3]),"-",as.character(quantile.2015[4])),
   paste(as.character(quantile.2015[4]),"-",as.character(quantile.2015[5])),
   paste(as.character(quantile.2015[5]),"-",as.character(quantile.2015[6]))
 ))
 
 #************************ 
 # Map in 1992
 #************************ 
 dev.new() 
 ggplot() + geom_polygon(data = joint.EU.df.1992,aes(x=long, y = lat, group = group,fill= colour.vector.1992),color="darkgray") + theme_bw(base_size = 15) + ditch_the_axes + coord_fixed(xlim = c(2787516, 5706892),  ylim = c(1547345, 5201736),ratio = 1.1) +
   # here we add the country borders
   geom_polygon(data = EU.nuts0.x.df.coordinate, aes(x = long, y = lat, group = group), fill = NA, size = 0.2,color="blue") + 
   
   # for gray maps 
   scale_fill_manual(values = gray.colors(5, start = 0.05, end = 0.8, gamma = 2.2, alpha = NULL),
                     breaks = gray.colors(5, start = 0.05, end = 0.8, gamma = 2.2, alpha = NULL),labels = labels.range.1992
   ) +
   # for colour maps
   # scale_fill_manual(values = c("khaki1","burlywood1","coral1","brown1","darkred"),
   #                    breaks =c("khaki1","burlywood1","coral1","brown1","darkred"),
   #                    labels = labels.range.1992) +
   theme(legend.position=c(0.18, 0.89),legend.title=element_text(size=11),legend.text=element_text(size=9)) +
   labs(fill = "Relative compensation per worker (PPP) (1992)")
 
dev.copy2eps(file="map_relative_tot_compensation_per_worker_1992.eps")

 
 #************************ 
 # Map in 2015
 #************************ 
 
 dev.new() 
 ggplot() + geom_polygon(data = joint.EU.df.2015,aes(x=long, y = lat, group = group,fill= colour.vector.2015),color="darkgray") + theme_bw(base_size = 15) + ditch_the_axes + coord_fixed(xlim = c(2787516, 5706892),  ylim = c(1547345, 5201736),ratio = 1.1) +
   # here we add the country borders
   geom_polygon(data = EU.nuts0.x.df.coordinate, aes(x = long, y = lat, group = group), fill = NA, size = 0.2,color="black") + 
   # for gray maps 
   scale_fill_manual(values = gray.colors(5, start = 0.05, end = 0.8, gamma = 2.2, alpha = NULL),
                     breaks = gray.colors(5, start = 0.05, end = 0.8, gamma = 2.2, alpha = NULL),labels = labels.range.2015
   ) +
   # for colour maps
   # scale_fill_manual(values = c("khaki1","burlywood1","coral1","brown1","darkred"),
   #                    breaks =c("khaki1","burlywood1","coral1","brown1","darkred"),
   #                    labels = labels.range.2015) +
   theme(legend.position=c(0.18, 0.89),legend.title=element_text(size=11),legend.text=element_text(size=9)) +
   labs(fill = "Relative compensation per worker (PPP) (2015)")

dev.copy2eps(file="map_relative_tot_compensation_per_worker_2015.eps")
